IndexedInstruments

Struct IndexedInstruments 

pub struct IndexedInstruments { /* private fields */ }
Indexed collection of exchanges, assets, and instruments.

Initialise incrementally via the IndexedInstrumentsBuilder, or all at once via the constructor.

The indexed collection is useful for creating efficient O(1) constant lookup state management systems where the state is keyed on an instrument, asset, or exchange.

For example uses cases, see the central rustrade crate EngineState design.

Index Relationships

  • ExchangeIndex: Unique index for each ExchangeId added during initialisation.
  • InstrumentIndex: Unique identifier for each Instrument added during initialisation.
  • AssetIndex: Unique identifier for each ExchangeAsset added during initialisation.

Implementations

Source

impl IndexedInstruments

pub fn new<Iter, I>(instruments: Iter) -> Self
where Iter: IntoIterator<Item = I>, I: Into<Instrument<ExchangeId, Asset>>,

Initialises a new IndexedInstruments from an iterator of Instruments.

This method indexes all unique exchanges, assets, and instruments, creating efficient lookup tables for each entity type.

Note that once an IndexedInstruments has been constructed, it cannot be mutated (this could invalidate existing index lookup tables).

For incremental initialisation, see the IndexedInstrumentsBuilder.

pub fn builder() -> IndexedInstrumentsBuilder

Returns a new IndexedInstrumentsBuilder useful for incremental initialisation of IndexedInstruments.

pub fn exchanges(&self) -> &[Keyed<ExchangeIndex, ExchangeId>]

Returns a reference to the ExchangeIndex <–> ExchangeId associations.

pub fn assets(&self) -> &[Keyed<AssetIndex, ExchangeAsset<Asset>>]

Returns a reference to the AssetIndex <–> ExchangeAsset associations.

pub fn instruments( &self, ) -> &[Keyed<InstrumentIndex, Instrument<Keyed<ExchangeIndex, ExchangeId>, AssetIndex>>]

Returns a reference to the InstrumentIndex <–> Instrument associations.

pub fn find_exchange_index( &self, exchange: ExchangeId, ) -> Result<ExchangeIndex, IndexError>

Finds the ExchangeIndex associated with the provided ExchangeId.

Arguments
  • exchange - The exchange ID to look up
Returns
  • Ok(ExchangeIndex) - exchange found.
  • Err(IndexError) - exchange not found.
pub fn find_exchange( &self, index: ExchangeIndex, ) -> Result<ExchangeId, IndexError>

pub fn find_asset_index( &self, exchange: ExchangeId, name: &AssetNameInternal, ) -> Result<AssetIndex, IndexError>

Finds the AssetIndex associated with the provided ExchangeId and AssetNameInterval.

Arguments
  • exchange - The ExchangeId associated with the asset.
  • name - The AssetNameInternal associated with the asset (eg/ “btc”, “usdt”, etc).
Returns
  • Ok(AssetIndex) - exchange asset found.
  • Err(IndexError) - exchange asset not found.
pub fn find_asset( &self, index: AssetIndex, ) -> Result<&ExchangeAsset<Asset>, IndexError>

pub fn find_instrument_index( &self, exchange: ExchangeId, name: &InstrumentNameInternal, ) -> Result<InstrumentIndex, IndexError>

Finds the InstrumentIndex associated with the provided ExchangeId and InstrumentNameInternal.

Arguments
  • exchange - The ExchangeId associated with the instrument.
  • name - The InstrumentNameInternal associated with the instrument (eg/ binance_spot_btc_usdt).
Returns
  • Ok(AssetIndex) - instrument found.
  • Err(IndexError) - instrument not found.
pub fn find_instrument( &self, index: InstrumentIndex, ) -> Result<&Instrument<Keyed<ExchangeIndex, ExchangeId>, AssetIndex>, IndexError>