Instrument

Struct Instrument 

pub struct Instrument<ExchangeKey, AssetKey> {
    pub exchange: ExchangeKey,
    pub name_internal: InstrumentNameInternal,
    pub name_exchange: InstrumentNameExchange,
    pub underlying: Underlying<AssetKey>,
    pub quote: InstrumentQuoteAsset,
    pub kind: InstrumentKind<AssetKey>,
    pub spec: Option<InstrumentSpec<AssetKey>>,
}
Comprehensive Instrument model, containing all the data required to subscribe to market data and generate correct orders.

Fields

exchange: ExchangeKeyname_internal: InstrumentNameInternalname_exchange: InstrumentNameExchangeunderlying: Underlying<AssetKey>quote: InstrumentQuoteAssetkind: InstrumentKind<AssetKey>spec: Option<InstrumentSpec<AssetKey>>

Implementations

Source

impl<ExchangeKey, AssetKey> Instrument<ExchangeKey, AssetKey>

pub fn new<NameInternal, NameExchange>( exchange: ExchangeKey, name_internal: NameInternal, name_exchange: NameExchange, underlying: Underlying<AssetKey>, quote: InstrumentQuoteAsset, kind: InstrumentKind<AssetKey>, spec: Option<InstrumentSpec<AssetKey>>, ) -> Self
where NameInternal: Into<InstrumentNameInternal>, NameExchange: Into<InstrumentNameExchange>,

Construct a new Instrument with the provided data.

This constructor assumes the InstrumentNameInternal can be constructed in the default style via the InstrumentNameInternal::new_from_exchange constructor.

pub fn spot<NameInternal, NameExchange>( exchange: ExchangeKey, name_internal: NameInternal, name_exchange: NameExchange, underlying: Underlying<AssetKey>, spec: Option<InstrumentSpec<AssetKey>>, ) -> Self
where NameInternal: Into<InstrumentNameInternal>, NameExchange: Into<InstrumentNameExchange>,

Construct a new Spot Instrument with the provided data.

This constructor assumes the InstrumentNameInternal can be constructed in the default style via the InstrumentNameInternal::new_from_exchange constructor.

pub fn map_exchange_key<NewExchangeKey>( self, exchange: NewExchangeKey, ) -> Instrument<NewExchangeKey, AssetKey>

Map this Instruments ExchangeKey to a new key.

pub fn map_asset_key_with_lookup<FnFindAsset, NewAssetKey, Error>( self, find_asset: FnFindAsset, ) -> Result<Instrument<ExchangeKey, NewAssetKey>, Error>
where FnFindAsset: Fn(&AssetKey) -> Result<NewAssetKey, Error>,

Map this Instruments AssetKey to a new key, using the provided lookup closure.